#!/bin/sh
#
# $FreeBSD: ports/mail/dk-milter/files/milter-dk.sh.in,v 1.3 2006/01/17 14:10:08 anray Exp $
#

# PROVIDE: milter-dk
# REQUIRE: DAEMON
# BEFORE: mail
# KEYWORD: shutdown

# Define these milterdk_* variables in one of these files:
#	/etc/rc.conf
#	/etc/rc.conf.local
#	/etc/rc.conf.d/milterdk
#
# milterdk_enable (bool):   Set to "NO" by default.
#                             Set it to "YES" to enable dk-milter
# milterdk_profiles (list):  Set to "" by default.
#                             Define your profiles here.
# milterdk_socket (str):    Path to the milter socket.
# milterdk_domain (str):    Domainpart of From: in mails to sign.
# milterdk_key (str):       Path to the private key file to sign with.
# milterdk_flags (str):     Flags passed to start command.
#
# milterdk_${profile}_* :   Variables per profile.
#                             Sockets must be different from each other.
#
# DO NOT CHANGE THESE DEFAULT VALUES HERE
#
milterdk_enable=${milterdk_enable:-"NO"}
milterdk_profiles=${milterdk_profiles:-}
milterdk_socket=${milterdk_socket:-"local:/var/run/dk-filter"}
milterdk_domain=${milterdk_domain:-"example.com"}
milterdk_key=${milterdk_key:-"/var/db/domainkeys/default.key.pem"}
## milterdk_flags expands escaped variables later.
milterdk_flags=${milterdk_flags:-"-d \${milterdk_domain\} -c nofws -H -m MSA \
-s \${milterdk_key\} -S default"}

. /etc/rc.subr

name="milterdk"
rcvar=`set_rcvar`

start_precmd="dk_prepcmd"
stop_postcmd="dk_prepcmd"
command="/usr/local/libexec/dk-filter"
_pidprefix="/var/run/dk-filter"
pidfile="${_pidprefix}.pid"

load_rc_config $name

if [ -n "$2" ]; then
    profile="$2"
    if [ "x${milterdk_profiles}" != "x" ]; then
	pidfile="${_pidprefix}.${profile}.pid"
	eval milterdk_enable="\${milterdk_${profile}_enable:-${milterdk_enable}}"
	eval milterdk_socket="\${milterdk_${profile}_socket:-}"
	if [ "x${milterdk_socket}" = "x" ];then
	    echo "You must define a socket (milterdk_${profile}_socket)"
	    exit 1
	fi
	eval milterdk_domain="\${milterdk_${profile}_domain:-${milterdk_domain}}"
	eval milterdk_key="\${milterdk_${profile}_key:-${milterdk_key}}"
	eval milterdk_flags="\${milterdk_${profile}_flags:-${milterdk_flags}}"
	command_args="-l -p ${milterdk_socket} -P ${pidfile}"
    else
	echo "$0: extra argument ignored"
    fi
else
    if [ "x${milterdk_profiles}" != "x" -a "x$1" != "x" ]; then
	if [ "x$1" != "xrestart" ]; then
	    for profile in ${milterdk_profiles}; do
		echo "===> milterdk profile: ${profile}"
		/usr/local/etc/rc.d/milter-dk.sh $1 ${profile}
		retcode="$?"
		if [ "0${retcode}" -ne 0 ]; then
		    failed="${profile} (${retcode}) ${failed:-}"
		else
		    success="${profile} ${success:-}"
		fi
	    done
	    exit 0
	else
	    restart_precmd=""
	fi
    else
	milterdk_flags=${milterdk_flags}
	command_args="-l -p ${milterdk_socket} -P ${pidfile}"
    fi
fi

dk_prepcmd ()
{
    if [ -S ${milterdk_socket##local:} ] ; then
        rm -f ${milterdk_socket##local:}
    elif [ -S ${milterdk_socket##unix:} ] ; then
        rm -f ${milterdk_socket##unix:}
    fi
}

run_rc_command "$1"
